@@ -30,6 +30,7 @@
 
 #include "callbacks.h"
 
+#include <sweep/sweep_i18n.h>
 #include <sweep/sweep_types.h>
 #include <sweep/sweep_undo.h>
 #include <sweep/sweep_sample.h>
@@ -72,7 +73,7 @@ sample_new_empty_cb (GtkWidget * widget, gpointer data)
   sw_view * view = (sw_view *)data;
 
   if (view == NULL) {
-    create_sample_new_dialog_defaults ();
+    create_sample_new_dialog_defaults (NULL);
   } else {
     create_sample_new_dialog_like (view->sample);
   }
@@ -108,10 +109,9 @@ static void
 view_init_repeater (sw_view * view, GtkFunction function, gpointer data)
 {
   function (data);
-
   if (view->repeater_tag <= 0) {
-    view->repeater_tag = gtk_timeout_add ((guint32)1000/ZOOM_FRAMERATE,
-					  function, data);
+    view->repeater_tag = g_timeout_add ((guint32)1000/ZOOM_FRAMERATE,
+					  (GSourceFunc) function, data);
   }
 }
 
@@ -121,7 +121,7 @@ repeater_released_cb (GtkWidget * widget, gpointer data)
   sw_view * view = (sw_view *)data;
 
   if (view->repeater_tag > 0) {
-    gtk_timeout_remove (view->repeater_tag);
+    g_source_remove(view->repeater_tag);
     view->repeater_tag = 0;
   }
 }
@@ -192,7 +192,7 @@ view_set_tool_cb (GtkWidget * widget, gpointer data)
   sw_tool_t tool;
 
   tool = (sw_tool_t)
-    GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(widget)));
+    GPOINTER_TO_INT(g_object_get_data (G_OBJECT(widget), "default"));
 
   view->current_tool = tool;
 
@@ -337,7 +337,7 @@ zoom_combo_changed_cb (GtkWidget * widget, gpointer data)
   sw_time_t zoom_time;
   sw_framecount_t zoom_length;
 
-  text = gtk_entry_get_text (GTK_ENTRY(widget));
+  text = (gchar *) gtk_entry_get_text (GTK_ENTRY(widget));
 
   if (!strcmp (text, "All")) {
     view_zoom_all (view);
@@ -372,7 +372,7 @@ sample_set_color_cb (GtkWidget * widget, gpointer data)
   sw_view * view = (sw_view *) data;
   gint color;
 
-  color = GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(widget)));
+  color = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(widget), "default"));
   sample_set_color (view->sample, color);
 }
 
@@ -447,7 +447,24 @@ mute_toggle_cb (GtkWidget * widget, gpointer data)
 }
 
 void
-play_view_cb (GtkWidget * widget, gpointer data)
+monitor_toggled_cb (GtkWidget * widget, gpointer data)
+{
+  sw_view * view = (sw_view *) data;
+  gboolean active;
+
+  active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget));
+  sample_set_monitor (view->sample, active);
+}
+
+void
+monitor_toggle_cb (GtkWidget * widget, gpointer data)
+{
+  sw_view * view = (sw_view *)data;
+  sample_set_monitor (view->sample, !view->sample->play_head->monitor);
+}
+
+void
+play_view_button_cb (GtkWidget * widget, gpointer data)
 {
   sw_view * view = (sw_view *) data;
   sw_head * head = view->sample->play_head;
@@ -458,17 +475,29 @@ play_view_cb (GtkWidget * widget, gpointer data)
 
   if (head->going && (head->scrubbing || !was_restricted)) {
     pause_playback_cb (widget, data);
-#if 0
-  } else if (head->going) {
-    sample_refresh_playmode (view->sample);
-#endif
   } else {
     play_view_all (view);
   }
 }
 
 void
-play_view_sel_cb (GtkWidget * widget, gpointer data)
+play_view_cb (GtkWidget * widget, gpointer data)
+{
+  sw_view * view = (sw_view *) data;
+  sw_head * head = view->sample->play_head;
+
+  head_set_rate (head, 1.0);
+  /*  head_set_restricted (head, FALSE);*/
+
+  if (head->going) {
+    pause_playback_cb (widget, data);
+  } else {
+    play_view_all (view);
+  }
+}
+
+void
+play_view_sel_button_cb (GtkWidget * widget, gpointer data)
 {
   sw_view * view = (sw_view *) data;
   sw_head * head = view->sample->play_head;
@@ -484,10 +513,27 @@ play_view_sel_cb (GtkWidget * widget, gpointer data)
 
   if (head->going && (head->scrubbing || was_restricted)) {
     pause_playback_cb (widget, data);
-#if 0
-  } else if (head->going) {
-    sample_refresh_playmode (view->sample);
-#endif
+  } else {
+    play_view_sel (view);
+  }
+}
+
+void
+play_view_sel_cb (GtkWidget * widget, gpointer data)
+{
+  sw_view * view = (sw_view *) data;
+  sw_head * head = view->sample->play_head;
+
+  if (view->sample->sounddata->sels == NULL) {
+    play_view_cb (widget, data);
+    return;
+  }
+
+  head_set_rate (head, 1.0);
+  /*  head_set_restricted (head, TRUE);*/
+
+  if (head->going) {
+    pause_playback_cb (widget, data);
   } else {
     play_view_sel (view);
   }
@@ -515,11 +561,11 @@ preview_cut_cb (GtkWidget * widget, gpointer data)
   sw_view * view = (sw_view *) data;
 
   sample_refresh_playmode (view->sample);
-  
+
   if (view->sample->sounddata->sels != NULL) {
     play_preview_cut (view);
   } else {
-    play_preview_cursor (view);
+    play_preroll (view);
   }
 }
 
@@ -665,10 +711,12 @@ sd_win_changed_cb (GtkWidget * widget)
   SampleDisplay * sd = SAMPLE_DISPLAY(widget);
   sw_view * v = sd->view;
 
-  gtk_signal_handler_block_by_data (GTK_OBJECT(v->adj), v);
+  g_signal_handlers_block_matched (GTK_OBJECT(v->adj), G_SIGNAL_MATCH_DATA, 0,
+									0, 0, 0, v);
   view_fix_adjustment (sd->view);
-  gtk_signal_handler_unblock_by_data (GTK_OBJECT(v->adj), v);
-
+	
+  g_signal_handlers_unblock_matched (GTK_OBJECT(v->adj), G_SIGNAL_MATCH_DATA, 0,
+								0, 0, 0, v); 
   view_refresh_hruler (v);
 }
 
@@ -679,12 +727,14 @@ adj_changed_cb (GtkWidget * widget, gpointer data)
   SampleDisplay * sd = SAMPLE_DISPLAY(v->display);
   GtkAdjustment * adj = GTK_ADJUSTMENT(v->adj);
 
-  gtk_signal_handler_block_by_data (GTK_OBJECT(sd), v);
+  g_signal_handlers_block_matched (GTK_OBJECT(GTK_OBJECT(sd)), G_SIGNAL_MATCH_DATA, 0,
+								0, 0, 0, v);
   sample_display_set_window(sd,
 			    (gint)adj->value,
 			    (gint)(adj->value + adj->page_size));
-  gtk_signal_handler_unblock_by_data (GTK_OBJECT(sd), v);
-
+  
+  g_signal_handlers_unblock_matched (GTK_OBJECT(GTK_OBJECT(sd)), G_SIGNAL_MATCH_DATA, 0,
+								0, 0, 0, v);
   view_refresh_hruler (v);
 }
 
@@ -697,19 +747,19 @@ adj_value_changed_cb (GtkWidget * widget, gpointer data)
 
   if (!v->sample->play_head->going || !v->following) {
 
-    gtk_signal_handler_block_by_data (GTK_OBJECT(sd), v);
+    g_signal_handlers_block_matched (GTK_OBJECT(GTK_OBJECT(sd)), G_SIGNAL_MATCH_DATA, 0,
+								0, 0, 0, v);
     sample_display_set_window(sd,
 			      (gint)adj->value,
 			      (gint)(adj->value + adj->page_size));
-    gtk_signal_handler_unblock_by_data (GTK_OBJECT(sd), v);
+    g_signal_handlers_unblock_matched (GTK_OBJECT(GTK_OBJECT(sd)), G_SIGNAL_MATCH_DATA, 0,
+								0, 0, 0, v);
+  }
 
-    if (v->following) {
-      sample_set_playmarker (v->sample, adj->value, TRUE);
-    }
-
-  } else {
-    /*    sample_set_scrubbing (v->sample, TRUE);*/
-    sample_set_playmarker (v->sample, adj->value, TRUE);
+  if (v->following) {
+    if (v->sample->user_offset < adj->value ||
+	v->sample->user_offset > adj->value + adj->page_size)
+      sample_set_playmarker (v->sample, adj->value + adj->page_size/2, TRUE);
   }
 
   view_refresh_hruler (v);  
@@ -866,23 +916,27 @@ paste_cb (GtkWidget * widget, gpointer data)
 void
 paste_mix_cb (GtkWidget * widget, gpointer data)
 {
-#ifdef DEVEL_CODE
   sw_view * view = (sw_view *)data;
   sw_sample * s = view->sample;
 
-  create_paste_mix_dialog (s);
-#endif
+  if (clipboard_width() > 0) {
+    create_paste_mix_dialog (s);
+  } else {
+    sample_set_tmp_message (s, _("Clipboard empty"));
+  }
 }
 
 void
 paste_xfade_cb (GtkWidget * widget, gpointer data)
 {
-#ifdef DEVEL_CODE
   sw_view * view = (sw_view *)data;
   sw_sample * s = view->sample;
 
-  do_paste_xfade (s);
-#endif
+  if (clipboard_width() > 0) {
+    create_paste_xfade_dialog (s);
+  } else {
+    sample_set_tmp_message (s, _("Clipboard empty"));
+  }
 }
 
 void
@@ -907,3 +961,70 @@ show_info_dialog_cb (GtkWidget * widget, gpointer data)
 
   sample_show_info_dialog (view->sample);
 }
+
+void
+hide_window_cb (GtkAccelGroup *accel_group,
+                                             GObject *acceleratable,
+                                             guint keyval,
+                                             GdkModifierType modifier)
+{
+	if (GTK_IS_WINDOW(acceleratable))
+  		g_signal_emit_by_name(G_OBJECT(acceleratable), "hide");
+}
+
+void 
+close_window_cb (GtkAccelGroup *accel_group,
+                                             GObject *acceleratable,
+                                             guint keyval,
+                                             GdkModifierType modifier)
+{
+	if (GTK_IS_WINDOW(acceleratable))
+  		g_signal_emit_by_name(G_OBJECT(acceleratable), "destroy");
+}
+ 
+/*
+ * Prime the label with the largest string then fetch the width.
+ * now we can lock the width via gtk_widget_set_usize() to prevent
+ * the wobble wobble caused by using a variable width font.
+ * Just a hackish replacement for the belated gtk_label_set_width_chars()
+ * don't try this at home kids, karma will get you. (oh well.. it works.) 
+ */
+void  
+hack_max_label_width_cb (GtkWidget *widget,
+							GtkStyle *previous_style,
+                            gpointer user_data)
+{
+  PangoRectangle logical_rect, ink_rect;
+  const gchar *saved;
+	
+  if (!GTK_IS_LABEL(widget))
+	  return;
+  saved = strdup(gtk_label_get_text(GTK_LABEL(widget)));
+  gtk_label_set_text(GTK_LABEL(widget), "00:00:00.0000");
+  pango_layout_get_extents (gtk_label_get_layout (GTK_LABEL(widget)), &ink_rect, &logical_rect);
+  gtk_label_set_text(GTK_LABEL(widget), saved);
+  
+  if(saved != NULL)
+  g_free((gpointer)saved);
+  gtk_widget_set_usize(GTK_WIDGET(widget),  PANGO_PIXELS (ink_rect.width), -1);
+}
+
+void  
+hack_max_combo_width_cb (GtkWidget *widget,
+							GtkStyle *previous_style,
+                            gpointer user_data)
+{
+  PangoRectangle logical_rect, ink_rect;
+  GtkWidget *tmp_entry;
+	
+  if (!GTK_IS_ENTRY(widget))
+	  return;
+  tmp_entry = gtk_entry_new();
+  gtk_widget_set_style(tmp_entry, gtk_style_copy(widget->style));
+  gtk_entry_set_text(GTK_ENTRY(tmp_entry), "00:00:00.0000.");
+  
+  pango_layout_get_extents (gtk_entry_get_layout (GTK_ENTRY(tmp_entry)), &ink_rect, &logical_rect);
+  gtk_widget_destroy(tmp_entry);
+  
+  gtk_widget_set_usize(GTK_WIDGET(GTK_ENTRY(widget)),  PANGO_PIXELS (ink_rect.width), -1);
+}
