@@ -119,6 +119,18 @@ mute_toggled_cb (GtkWidget * widget, gpointer data);
 void
 mute_toggle_cb (GtkWidget * widget, gpointer data);
 
+void
+monitor_toggled_cb (GtkWidget * widget, gpointer data);
+
+void
+monitor_toggle_cb (GtkWidget * widget, gpointer data);
+
+void
+play_view_button_cb (GtkWidget * widget, gpointer data);
+
+void
+play_view_sel_button_cb (GtkWidget * widget, gpointer data);
+
 void
 play_view_cb (GtkWidget * widget, gpointer data);
 
@@ -257,4 +269,26 @@ normalise_cb (GtkWidget * widget, gpointer data);
 void
 show_info_dialog_cb (GtkWidget * widget, gpointer data);
 
+void 
+close_window_cb(GtkAccelGroup *accel_group,
+                                             GObject *acceleratable,
+                                             guint keyval,
+                                             GdkModifierType modifier);
+											 
+void 
+hide_window_cb(GtkAccelGroup *accel_group,
+                                             GObject *acceleratable,
+                                             guint keyval,
+                                             GdkModifierType modifier);
+											 
+void  
+hack_max_label_width_cb (GtkWidget *widget,
+							GtkStyle *previous_style,
+                            gpointer user_data);
+							
+void  
+hack_max_combo_width_cb (GtkWidget *widget,
+							GtkStyle *previous_style,
+                            gpointer user_data);
+
 #endif /* __CALLBACKS_H__ */
