@@ -23,6 +23,19 @@
 
 #include <sweep/sweep_types.h>
 
+void *
+sweep_large_alloc_zero (size_t len, int prot);
+
+void *
+sweep_large_alloc_data (size_t len, void * data, int prot);
+
+
+sw_framecount_t
+clipboard_width (void);
+
+sw_edit_buffer *
+edit_buffer_ref (sw_edit_buffer * eb);
+
 sw_edit_buffer *
 edit_buffer_from_sample (sw_sample * sample);
 
@@ -32,8 +45,8 @@ edit_buffer_destroy (sw_edit_buffer * eb);
 sw_sample *
 splice_out_sel (sw_sample * sample);
 
-sw_sounddata *
-splice_in_eb (sw_sounddata * sounddata, sw_edit_buffer * eb);
+sw_sample *
+splice_in_eb (sw_sample * sample, sw_edit_buffer * eb);
 
 sw_sample *
 crop_out (sw_sample * sample);
@@ -66,10 +79,12 @@ void
 do_paste_insert (sw_sample * sample);
 
 void
-do_paste_mix (sw_sample * sample);
+do_paste_mix (sw_sample * sample, gdouble src_gain, gdouble dest_gain);
 
 void
-do_paste_xfade (sw_sample * sample);
+do_paste_xfade (sw_sample * sample, gdouble src_gain_start,
+		gdouble src_gain_end, gdouble dest_gain_start,
+		gdouble dest_gain_end);
 
 sw_op_instance *
 do_paste_over (sw_sample * in, sw_sample ** out);
