@@ -18,6 +18,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
@@ -47,6 +51,15 @@ sel_new (sw_framecount_t start, sw_framecount_t end)
   return sel;
 }
 
+void
+sel_free (sw_sel * sel)
+{
+  if (!sel)
+	return;
+
+  g_free(sel);
+}
+
 sw_sel *
 sel_copy (sw_sel * sel)
 {
